'use strict';

var react = require('react');
var jsxRuntime = require('react/jsx-runtime');

var RADIUS_TOKEN = {
  /**
   * Content banners(Primary), Full-screen dialogs, Lists, Navigation bars, Header Progress indicators, Side sheets, Tabs, Top app bars
   */
  "rounded-none": "0",
  /**
   * Tooltip pointer
   */
  "rounded-xsmall": "0.0625rem",
  /**
   * Buttons(Small, Tiny), Checkbox, Segment tab item
   */
  "rounded-small": "0.375rem",
  /**
   * Buttons(Large, Medium), Content banners(Secondary), Context menu, Optionlist, Select, Textfield, Text area, Tooltip
   */
  "rounded-base": "0.5rem",
  /**
   * Page banner, Card
   */
  "rounded-large": "0.75rem",
  /**
   * Modal
   */
  "rounded-xlarge": "1rem",
  /**
   * Avata, Slider Track, Switch, Tag, Toast
   */
  "rounded-full": "50%"
};

var THICKNESS_TOKEN = {
  /**
   * Default
   */
  "border-1": "0.0625rem",
  // 1px
  /**
   * 파일 업로더 Drag on 상태 border 캠페인 채널 Card hover 또는 유효성 에러 상태 border (MP)
   */
  "border-2": "0.125rem",
  // 2px
  /**
   * Content banner(Primary) 왼쪽 사이드 border
   */
  "border-4": "0.25rem",
  // 4px
  /**
   * System icon(Line) border
   */
  "border-icon": "0.075rem",
  // 1.2px
  /**
   * 가로 요소 사이에 테두리를 추가합니다.
   */
  "divide-x": "0.0625rem",
  // 1px
  /**
   * 쌓인 요소 사이에 테두리를 추가합니다.
   */
  "divide-y": "0.0625rem" // 1px
};

var PALETTE_TOKEN = {
  "slate-50": "#F8F9FB",
  "slate-100": "#E2E5E9",
  "slate-200": "#DBDEE3",
  "slate-300": "#BCC0C6",
  "slate-400": "#9FA3AB",
  "slate-500": "#717680",
  "slate-600": "#4B515B",
  "slate-700": "#24282F",
  "slate-800": "#1D2027",
  "slate-900": "#15181E",
  "slate-tint-15": "rgba(115, 120, 130, 0.15)",
  "slate-black": "#000000",
  "slate-white": "#FFFFFF",
  "imBlue-50": "#E8F0FF",
  "imBlue-100": "#C6DBFF",
  "imBlue-200": "#99BDFF",
  "imBlue-300": "#70A2FF",
  "imBlue-400": "#4788FF",
  "imBlue-500": "#1A6DFF",
  "imBlue-600": "#0056F5",
  "imBlue-700": "#0047CC",
  "imBlue-800": "#0039A3",
  "imBlue-900": "#002B7A",
  "imBlue-tint-15": "rgba(26, 109, 255, 0.15)",
  "mint-50": "#E5FBF6",
  "mint-100": "#CCF7EB",
  "mint-200": "#99F1DA",
  "mint-300": "#73EBCC",
  "mint-400": "#4CE6BF",
  "mint-500": "#00DBA3",
  "mint-600": "#00BA8B",
  "mint-700": "#009972",
  "mint-800": "#00785A",
  "mint-900": "#005841",
  "mint-tint-15": "rgba(0, 219, 163, 0.15)",
  "raspberry-50": "#FFF2F3",
  "raspberry-100": "#FFE6E8",
  "raspberry-200": "#FECDD3",
  "raspberry-300": "#FEA3AC",
  "raspberry-400": "#FE7683",
  "raspberry-500": "#FE5868",
  "raspberry-600": "#DD3344",
  "raspberry-700": "#C81E2E",
  "raspberry-800": "#A51927",
  "raspberry-900": "#88131A",
  "raspberry-tint-15": "rgba(254, 88, 104, 0.15)",
  "mango-50": "#FFF6E7",
  "mango-100": "#FFF2DB",
  "mango-200": "#FFE0AC",
  "mango-300": "#FFD388",
  "mango-400": "#FFC258",
  "mango-500": "#FFA811",
  "mango-600": "#E5970F",
  "mango-700": "#D68C0C",
  "mango-800": "#99650A",
  "mango-900": "#734C08",
  "mango-tint-15": "rgba(255, 168, 17, 0.15)",
  "skyblue-50": "#F3F8FF",
  "skyblue-100": "#E0EFFF",
  "skyblue-200": "#CEE5FF",
  "skyblue-300": "#BCDBFF",
  "skyblue-400": "#AAD1FF",
  "skyblue-500": "#85BDFF",
  "skyblue-600": "#6A97CC",
  "skyblue-700": "#5D84B3",
  "skyblue-800": "#4C6C91",
  "skyblue-900": "#314760",
  "skyblue-tint-15": "rgba(133, 189, 255, 0.15)",
  "grape-50": "#F5EDFF",
  "grape-100": "#EBDBFF",
  "grape-200": "#DCC0FF",
  "grape-300": "#C79CFF",
  "grape-400": "#B378FF",
  "grape-500": "#9A4BFF",
  "grape-600": "#8340D9",
  "grape-700": "#7438BF",
  "grape-800": "#9A4BFF",
  "grape-900": "#55298C",
  "grape-tint-15": "rgba(154, 75, 255, 0.15)"
};

var COLOR_TOKEN = Object.freeze({
  /**
   * Page 배경색
   */
  bg: {
    light: "#EDF0F4",
    // 레거시에서 사용하는 색상이라 파레트에 없다고 합니다.
    dark: PALETTE_TOKEN["slate-black"]
  },
  /**
   * Card, Modal, Popover 등의 컴포넌트 배경색
   */
  surface: {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-900"]
  },
  /**
   * Card, Modal, Popover 등의 컴포넌트 보조 배경색
   */
  "surface-sub": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 설명
   */
  "surface-slate": {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * 설명
   */
  "surface-accent": {
    light: PALETTE_TOKEN["skyblue-50"],
    dark: PALETTE_TOKEN["skyblue-tint-15"]
  },
  /**
   * 배지를 포함한 Critical 요소의 배경 색상으로, 오류 및 즉각적인 조치가 필요한 중요한 이벤트에 사용합니다.
   */
  "surface-critical": {
    light: PALETTE_TOKEN["raspberry-50"],
    dark: PALETTE_TOKEN["raspberry-tint-15"]
  },
  /**
   * 경고 요소의 배경 색상으로, 사용자에게 조치가 필요함을 알리고 배지, 배너 및 예외 목록에 적용됩니다.
   */
  "surface-warning": {
    light: PALETTE_TOKEN["mango-50"],
    dark: PALETTE_TOKEN["mango-tint-15"]
  },
  /**
   * 배지를 포함한 성공 요소의 배경 색상으로, 사용자 행동의 성공 또는 성장을 설명하는 것과 같이 긍정적인 것을 나타냅니다.
   */
  "surface-success": {
    light: PALETTE_TOKEN["mint-50"],
    dark: PALETTE_TOKEN["mint-tint-15"]
  },
  /**
   * 정보 요소의 배경 색상으로, 즉각적인 조치가 필요하지 않은 중요한 요소를 나타냅니다. 정보 배너 및 배지, 새로운 정보에 주의를 환기시키는 표시기, 로드 또는 진행률 표시줄, 데이터 시각화와 함께 사용됩니다.
   */
  "surface-highlight": {
    light: PALETTE_TOKEN["skyblue-50"],
    dark: PALETTE_TOKEN["skyblue-tint-15"]
  },
  /** Primary textfield 배경색 */
  "field-primary": {
    light: PALETTE_TOKEN["imBlue-50"],
    dark: PALETTE_TOKEN["imBlue-tint-15"]
  },
  /** Secondary textfield 배경색 */
  "field-secondary": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-700"]
  },
  /**
   * Textfield의 Typing 상태
   * 선택된 체크박스와 라디오 버튼의 채우기 색상
   */
  focus: {
    light: PALETTE_TOKEN["imBlue-500"],
    dark: PALETTE_TOKEN["imBlue-400"]
  },
  /**
   * Primary button 배경색
   */
  "action-primary": {
    light: PALETTE_TOKEN["imBlue-500"],
    dark: PALETTE_TOKEN["imBlue-400"]
  },
  /**
   * Primary button hover color
   */
  "action-primary-hover": {
    light: PALETTE_TOKEN["imBlue-300"],
    dark: PALETTE_TOKEN["imBlue-300"]
  },
  /**
   * Primary button pressed color
   */
  "action-primary-pressed": {
    light: PALETTE_TOKEN["imBlue-200"],
    dark: PALETTE_TOKEN["imBlue-200"]
  },
  /**
   * Primary button disabled color
   */
  "action-primary-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Secondary button 배경색
   */
  "action-secondary": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-900"]
  },
  /**
   * secondary button hover color
   */
  "action-secondary-hover": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * secondary button pressed color
   */
  "action-secondary-pressed": {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-700"]
  },
  /**
   * secondary button disabled color
   */
  "action-secondary-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Floating action button(FAB) 배경색
   */
  "action-tertiary": {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * Floating action button(FAB) hover color
   */
  "action-tertiary-hover": {
    light: PALETTE_TOKEN["slate-700"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Critical button 배경색
   */
  "action-critical": {
    light: PALETTE_TOKEN["raspberry-500"],
    dark: PALETTE_TOKEN["raspberry-500"]
  },
  /**
   * Critical button hover color
   */
  "action-critical-hover": {
    light: PALETTE_TOKEN["raspberry-300"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Critical button pressed color
   */
  "action-critical-pressed": {
    light: PALETTE_TOKEN["raspberry-200"],
    dark: PALETTE_TOKEN["raspberry-300"]
  },
  /**
   * Critical button disabled color
   */
  "action-critical-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Floating action button(FAB) 배경색
   */
  "action-toggle": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * 특정 요소를 투명도가 있는 어두운 색상으로 가려야 할 때 사용 (Modal, Side sheet)
   */
  backdrop: {
    light: "rgba(11, 12, 14, 0.75)",
    dark: "rgba(0, 0, 0, 0.75)"
  },
  /**
   * Default border color
   */
  border: {
    light: PALETTE_TOKEN["slate-200"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Default border hover color (액션 기능이 있을 경우)
   */
  "border-hover": {
    light: PALETTE_TOKEN["imBlue-300"],
    dark: PALETTE_TOKEN["imBlue-700"]
  },
  /**
   * Sub border color
   */
  "border-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Sub border color
   */
  "border-minimal": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical border color
   */
  "border-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical border hover color (액션 기능이 있을 경우)
   */
  "border-critical-hover": {
    light: PALETTE_TOKEN["raspberry-300"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning border color
   */
  "border-warning": {
    light: PALETTE_TOKEN["mango-600"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Success border color
   */
  "border-success": {
    light: PALETTE_TOKEN["mint-600"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Informative border color
   */
  "border-highlight": {
    light: PALETTE_TOKEN["skyblue-800"],
    dark: PALETTE_TOKEN["skyblue-600"]
  },
  /**
   * 요소 사이 구분 선
   */
  divide: {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 요소 사이의 보조 구분 선
   */
  "divide-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 요소 사이의 보조 구분 선
   */
  "divide-minimal": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * Default text, Primary label color
   */
  text: {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Sub text, Secondary label, Placeholder color
   */
  "text-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-500"]
  },
  /**
   * Disabled text, Placeholder disabled text color
   */
  "text-disabled": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical state text color
   */
  "text-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical text hover color (액션 기능이 있을 경우)
   */
  "text-critical-hover": {
    light: PALETTE_TOKEN["raspberry-400"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning state text color
   */
  "text-warning": {
    light: PALETTE_TOKEN["mango-700"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Warning text hover color (액션 기능이 있을 경우)
   */
  "text-warning-hover": {
    light: PALETTE_TOKEN["mango-400"],
    dark: PALETTE_TOKEN["mango-200"]
  },
  /**
   * Success text color
   */
  "text-success": {
    light: PALETTE_TOKEN["mint-700"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Link text, Primary text button color
   */
  "text-primary": {
    light: PALETTE_TOKEN["imBlue-500"],
    dark: PALETTE_TOKEN["imBlue-400"]
  },
  /**
   * Link text, Primary text button hover color
   */
  "text-primary-hover": {
    light: PALETTE_TOKEN["imBlue-300"],
    dark: PALETTE_TOKEN["imBlue-300"]
  },
  /**
   * Secondary text button color
   */
  "text-secondary": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-300"]
  },
  /**
   * Secondary text button hover color
   */
  "text-secondary-hover": {
    light: PALETTE_TOKEN["slate-400"],
    dark: PALETTE_TOKEN["slate-200"]
  },
  /**
   * Primary, Critical, Text on button text color
   */
  "text-on": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Default icon color
   */
  icon: {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Sub icon color
   */
  "icon-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-500"]
  },
  /**
   * Disabled icon color
   */
  "icon-disabled": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical state icon color
   */
  "icon-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical icon hover color (액션 기능이 있을 경우)
   */
  "icon-critical-hover": {
    light: PALETTE_TOKEN["raspberry-400"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning state icon color
   */
  "icon-warning": {
    light: PALETTE_TOKEN["mango-700"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Warning icon hover color (액션 기능이 있을 경우)
   */
  "icon-warning-hover": {
    light: PALETTE_TOKEN["mango-400"],
    dark: PALETTE_TOKEN["mango-200"]
  },
  /**
   * Success icon color
   */
  "icon-success": {
    light: PALETTE_TOKEN["mint-700"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Primary button icon color
   */
  "icon-primary": {
    light: PALETTE_TOKEN["imBlue-500"],
    dark: PALETTE_TOKEN["imBlue-400"]
  },
  /**
   * Primary button icon hover color
   */
  "icon-primary-hover": {
    light: PALETTE_TOKEN["imBlue-300"],
    dark: PALETTE_TOKEN["imBlue-300"]
  },
  /**
   * Secondary button icon color
   */
  "icon-secondary": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-300"]
  },
  /**
   * Secondary button icon hover color
   */
  "icon-secondary-hover": {
    light: PALETTE_TOKEN["slate-400"],
    dark: PALETTE_TOKEN["slate-200"]
  },
  /**
   * Primary, Critical, Text on button text color
   */
  "icon-on": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-white"]
  }
});

var SPACING_TOKEN = {
  "space-0": "0",
  "space-px": "1px",
  "space-05": "2px",
  "space-1": "0.25rem",
  "space-15": "0.375rem",
  "space-2": "0.5rem",
  "space-25": "0.625rem",
  "space-3": "0.75rem",
  "space-4": "1rem",
  "space-5": "1.25rem",
  "space-6": "1.5rem",
  "space-7": "1.75rem",
  "space-8": "2rem",
  "space-10": "2.5rem",
  "space-12": "3rem",
  "space-16": "4rem",
  "space-20": "5rem",
  "space-24": "6rem",
  "space-28": "7rem",
  "space-32": "8rem",
  "space-40": "10rem"
};

var FONT_FAMILY = "Pretendard";

var FONT_SIZE = {
  "2xsmall": "11px",
  xsmall: "0.75rem",
  small: "0.875rem",
  base: "1rem",
  large: "1.125rem",
  xlarge: "1.25rem",
  "2xlarge": "1.5rem",
  "3xlarge": "1.875rem",
  "4xlarge": "2.25rem"
};

var FONT_WEIGHT = {
  normal: 400,
  medium: 500,
  semibold: 600,
  bold: 700
};

var LINE_HEIGHT = {
  "leading-3": "0.75rem",
  "leading-4": "1rem",
  "leading-5": "1.25rem",
  "leading-6": "1.5rem",
  "leading-7": "1.75rem",
  "leading-8": "2rem",
  "leading-9": "2.25rem",
  "leading-10": "2.5rem",
  "leading-none": "100%",
  "leading-tight": "125%",
  "leading-snug": "137.5%",
  "leading-normal": "150%",
  "leading-relaxed": "162.5%",
  "leading-loose": "200%"
};

var CORE_TOKEN = {
  fontFamily: FONT_FAMILY,
  fontSize: FONT_SIZE,
  fontWeight: FONT_WEIGHT,
  lineHeight: LINE_HEIGHT
};

var Semantic = {
  /** 프로모션 비주얼 타이틀 */
  h1: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE["4xlarge"],
    lineHeight: LINE_HEIGHT["leading-10"]
  },
  /** 프로모션 비주얼 타이틀(강조시에만 사용) */
  "h1-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE["4xlarge"],
    lineHeight: LINE_HEIGHT["leading-10"]
  },
  /** 페이지 타이틀 */
  "h2-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE["3xlarge"],
    lineHeight: LINE_HEIGHT["leading-9"]
  },
  /** 오늘의 할 일, 통계 등의 숫자 요약 primary */
  "h3-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE["2xlarge"],
    lineHeight: LINE_HEIGHT["leading-7"]
  },
  /** 오늘의 할 일, 통계 등의 숫자 요약 primary */
  "h4-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.xlarge,
    lineHeight: LINE_HEIGHT["leading-6"]
  },
  /** 프로모션 배너 타이틀 */
  h5: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE.large,
    lineHeight: LINE_HEIGHT["leading-7"]
  },
  /** 카드 타이틀, 프로모션 배너 타이틀(강조시에만 사용) */
  "h5-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.large,
    lineHeight: LINE_HEIGHT["leading-7"]
  },
  h6: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE.base,
    lineHeight: LINE_HEIGHT["leading-6"]
  },
  /** (only card) 서브 타이틀 */
  "h6-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.base,
    lineHeight: LINE_HEIGHT["leading-6"]
  },
  /** 큰 버튼 텍스트 */
  p16: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE.base,
    lineHeight: LINE_HEIGHT["leading-6"]
  },
  "p16-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.base,
    lineHeight: LINE_HEIGHT["leading-6"]
  },
  /** 기본 텍스트 */
  p14: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE.small,
    lineHeight: LINE_HEIGHT["leading-5"]
  },
  /** 기본 텍스트(강조시에만 사용) */
  "p14-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.small,
    lineHeight: LINE_HEIGHT["leading-5"]
  },
  /** 서브 텍스트 */
  p12: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE.xsmall,
    lineHeight: LINE_HEIGHT["leading-4"]
  },
  /** 서브 텍스트(강조시에만 사용) */
  "p12-bold": {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.xsmall,
    lineHeight: LINE_HEIGHT["leading-4"]
  },
  /** 라벨 */
  l14: {
    fontWeight: FONT_WEIGHT.bold,
    fontSize: FONT_SIZE.small,
    lineHeight: LINE_HEIGHT["leading-5"]
  },
  /** tag, chips, badge, etc */
  l11: {
    fontWeight: FONT_WEIGHT.normal,
    fontSize: FONT_SIZE["2xsmall"],
    lineHeight: LINE_HEIGHT["leading-3"]
  }
};

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);
  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }
  return keys;
}
function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }
  return target;
}
function _defineProperty(obj, key, value) {
  key = _toPropertyKey(key);
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}
function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}
function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};
  var target = _objectWithoutPropertiesLoose(source, excluded);
  var key, i;
  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }
  return target;
}
function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];
  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (hint === "string" ? String : Number)(input);
}
function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");
  return typeof key === "symbol" ? key : String(key);
}

var _excluded = ["children", "semanticToken", "style", "as"];
var _Typography = function _Typography(_ref, ref) {
  var children = _ref.children,
    _ref$semanticToken = _ref.semanticToken,
    semanticToken = _ref$semanticToken === void 0 ? "p14" : _ref$semanticToken,
    style = _ref.style,
    _ref$as = _ref.as,
    as = _ref$as === void 0 ? "p" : _ref$as,
    restProps = _objectWithoutProperties(_ref, _excluded);
  var Element = as;
  return /*#__PURE__*/jsxRuntime.jsx(Element, _objectSpread2(_objectSpread2({
    ref: ref,
    style: _objectSpread2(_objectSpread2({
      fontFamily: FONT_FAMILY
    }, Semantic[semanticToken]), style)
  }, restProps), {}, {
    children: children
  }));
};
var Typography = /*#__PURE__*/react.forwardRef(_Typography);

exports.COLOR_TOKEN = COLOR_TOKEN;
exports.CORE_TOKEN = CORE_TOKEN;
exports.PALETTE_TOKEN = PALETTE_TOKEN;
exports.RADIUS_TOKEN = RADIUS_TOKEN;
exports.SPACING_TOKEN = SPACING_TOKEN;
exports.Semantic = Semantic;
exports.THICKNESS_TOKEN = THICKNESS_TOKEN;
exports.Typography = Typography;
